package com.ruoyi.ai.service;

import java.util.List;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiHelp;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * 【帮助管理】Service接口
 * 
 * @author shi
 * @date 2025-11-13
 */
public interface IAiHelpService {

    /**
     * 查询【帮助管理】
     * 
     * @param id 【帮助管理】主键
     * @return 【帮助管理】
     */
    AiHelp selectAiHelpById(Long id);

    /**
     * 查询【帮助管理】列表
     * 
     * @param aiHelp 【帮助管理】
     * @return 【帮助管理】集合
     */
    List<AiHelp> selectAiHelpList(AiHelp aiHelp);

    /**
     * 分页查询【帮助管理】列表
     *
     * @param aiHelp 【帮助管理】
     * @return 【帮助管理】集合
     */
    IPage<AiHelp> selectAiHelpPage(Page page, AiHelp aiHelp);

    /**
     * 新增【帮助管理】
     * 
     * @param aiHelp 【帮助管理】
     * @return 结果
     */
    int insertAiHelp(AiHelp aiHelp);

    /**
     * 修改【帮助管理】
     * 
     * @param aiHelp 【帮助管理】
     * @return 结果
     */
    int updateAiHelp(AiHelp aiHelp);

    /**
     * 批量删除【帮助管理】
     * 
     * @param ids 需要删除的【帮助管理】主键集合
     * @return 结果
     */
    int deleteAiHelpByIds(Long[] ids);

    /**
     * 删除【帮助管理】信息
     * 
     * @param id 【帮助管理】主键
     * @return 结果
     */
    int deleteAiHelpById(Long id);
}
